@@ -1,9 +1,9 @@
 from ground.hints import Point
 from reprit.base import generate_repr
 
-from .abcs import Node
 from .edge import Edge
 from .location import Location
+from .node import Node
 from .trapezoid import Trapezoid
 
 
